summaryrefslogtreecommitdiff
path: root/include/function.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/function.h')
-rw-r--r--include/function.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/function.h b/include/function.h
index ff4396c..c78fdd6 100644
--- a/include/function.h
+++ b/include/function.h
@@ -94,11 +94,11 @@ public:
/**
* Method that gets called every time the function is executed
* @param request Request object
* @param params The parameters that were passed
* @return Variable Return value
*/
- virtual Value invoke(Request &request, Parameters &params)
+ virtual Value invoke(Environment &environment, Parameters &params)
{
return nullptr;
}
@@ -94,11 +94,11 @@ public:
/**
* Method that gets called every time the function is executed
- * @param request Request object
+ * @param environment Environment object
* @param params The parameters that were passed
* @return Variable Return value